
// RcppArmadilloGenerated.h: Autoconf-updated file for LAPACK and OpenMP choices
//
// Copyright (C)  2013 - 2021  Dirk Eddelbuettel
//
// This file is part of RcppArmadillo.
//
// RcppArmadillo is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
//
// RcppArmadillo is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with RcppArmadillo.  If not, see <http://www.gnu.org/licenses/>.

#ifndef RcppArmadillo__RcppArmadilloConfigGenerated__h
#define RcppArmadillo__RcppArmadilloConfigGenerated__h

#ifndef ARMA_USE_OPENMP
// from configure test for OpenMP based on how R is configured, and whether g++ new enough
#define ARMA_DONT_USE_OPENMP 1
#endif

#endif
